@@ -1,6 +1,6 @@
 package Proc::tored::Manager;
 # ABSTRACT: OO interface to creating a proctored service
-$Proc::tored::Manager::VERSION = '0.09';
+$Proc::tored::Manager::VERSION = '0.10';
 
 use strict;
 use warnings;
@@ -96,6 +96,13 @@ sub _build_pause_flag {
   Proc::tored::Flag->new(touch_file_path => $self->pause_file);
 }
 
+
+has trap_signals => (
+  is  => 'ro',
+  isa => SignalList,
+  default => sub {[]},
+);
+
 has lock_file => (
   is  => 'lazy',
   isa => NonEmptyStr,
@@ -129,7 +136,12 @@ sub service {
   die 'expected a CODE ref' unless is_CodeRef($code);
 
   if (my $guard = $self->run_lock) {
-    until ($self->is_stopped) {
+    my $signalled = 0;
+
+    $SIG{$_} = sub { $signalled = 1 }
+      foreach @{$self->trap_signals};
+
+    until ($signalled || $self->is_stopped) {
       if ($self->is_paused) {
         sleep 0.2;
         next;
@@ -138,6 +150,9 @@ sub service {
       last unless $code->();
     }
 
+    undef $SIG{$_}
+      foreach @{$self->trap_signals};
+
     return 1;
   }
 
@@ -204,10 +219,7 @@ sub run_lock {
     $file->spew("$$\n");
 
     # Create guard object that releases the pidfile once out of scope
-    return guard {
-      $file->append({truncate => 1})
-        if $self->is_running;
-    };
+    return guard { $file->remove if $self->is_running };
   }
 
   return;
@@ -263,7 +275,7 @@ Proc::tored::Manager - OO interface to creating a proctored service
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -315,6 +327,11 @@ Unless manually specified, the stop file's path is L</dir>/L</name>.stopped.
 
 Unless manually specified, the pause file's path is L</dir>/L</name>.paused.
 
+=item trap_signals
+
+An optional array of signals (suitable for use in C<%SIG>) allowed to end the
+L</service> loop. Unless specified, no signal handlers are installed.
+
 =back
 
 =head1 METHODS
