@@ -1,19 +1,21 @@
 package Proc::tored::Types;
 # ABSTRACT: Type constraints used by Proc::tored
-$Proc::tored::Types::VERSION = '0.09';
+$Proc::tored::Types::VERSION = '0.10';
 use strict;
 use warnings;
-use Types::Standard 'Str';
+use Types::Standard -types;
 use Type::Utils -all;
 use Type::Library -base,
   -declare => qw(
     NonEmptyStr
     Dir
+    SignalList
   );
 
 
 declare NonEmptyStr, as Str, where { $_ =~ /\S/ };
 declare Dir, as NonEmptyStr, where { -d $_ && -w $_ };
+declare SignalList, as ArrayRef[Str], where { @$_ || $^O ne 'MSWin32' };
 
 1;
 
@@ -29,7 +31,7 @@ Proc::tored::Types - Type constraints used by Proc::tored
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 TYPES
 
@@ -41,6 +43,10 @@ A C<Str> that contains at least one non-whitespace character.
 
 A L</NonEmptyStr> that is a valid, writable directory path.
 
+=head2 SignalList
+
+An array ref of strings suitable for use in C<%SIG>, except on MSWin32 systems.
+
 =head1 AUTHOR
 
 Jeff Ober <jeffober@gmail.com>
